AudioRoute class final

Handle for metrics, events, and dynamic detachment of one route.

Properties

done Future<void>
Completes when the route sink has been finalized and closed.
no setter
events Stream<AudioRouteEvent>
Broadcast events produced by this route.
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
Stable route identifier.
no setter
metrics AudioRouteMetrics
Current immutable counters.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state AudioRouteState
Current route lifecycle.
no setter

Methods

detach({bool drain = true}) Future<void>
Dynamically detaches this route.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited